==> openGion_dev_5.6.6.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_SEQUENCE_SQLSERVER.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

/**
 * TableFilter_SEQUENCE_SQLSERVER は、TableUpda インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。
 *
 * ここでは、シーケンス一覧の検索結果より、GF09 のシーケンス定義テーブルから
 * 必要な情報を取得し、シーケンス作成スクリプトを作成します。
 *
 * この処理を実行するには、DBTableModelのカラムとして、
 *  SEQNAME,INCREBY,STARTVAL,MINVAL,MAXVAL,FGCYCLE,SUCACHE
 * が必要です。
 *
 * ※SQLServerに対して生成されるスクリプトでは、INCREBY,MINVAL,MAXVAL,FGCYCLE,SUCACHEは無視されます。
 *   なお、SQLServerではシーケンスはサポートされていないため、シーケンス名と同じ名前のシーケンス採番テーブルを生成し、
 *   これを1ずつ加算してアップデートすることで、シーケンスをエミュレートします。(この実装は未テストです)
 *
 * @og.rev 5.1.9.0 (2010/08/01) DB定義DB・シーケンス定義追加
 * @version  0.9.0  2010/08/01
 * @author   Hiroki Nakamura
 * @since    JDK1.1,
 */
public class TableFilter_SEQUENCE_SQLSERVER extends TableFilter_SEQUENCE {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.1.9.0 (2010/08/01)" ;

	/**
	 * シーケンス作成の処理を実行します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	シーケンス作成
	 */
	@Override
	protected String makeLineList( final int[] clmNo,final String[] data ) {
		StringBuilder buf = new StringBuilder();

		if( isXml ) { buf.append( EXEC_START_TAG ).append( CR ); }
		buf.append( "CREATE TABLE " ).append( data[clmNo[SEQNAME]] ).append( CR );
		buf.append( "(SEQID INT NOT NULL)" ).append( CR );
		if( isXml )	{ buf.append( EXEC_END_TAG ); }
		else		{ buf.append( ";" ); }

		buf.append( CR ).append( CR );

		if( isXml ) { buf.append( EXEC_START_TAG ).append( CR ); }
		buf.append( "INSERT INTO " ).append( data[clmNo[SEQNAME]] ).append( CR );
		int startVal = Integer.valueOf( data[clmNo[STARTVAL]] );
		if( startVal < 0 ) { startVal = 0; }
		buf.append( "VALUES (" ).append( startVal ).append( ")" ).append( CR );
		if( isXml )	{ buf.append( EXEC_END_TAG ); }
		else		{ buf.append( ";" ); }

		buf.append( CR );

		return buf.toString();
	}
}

==> openGion_dev_5.9.1.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_SEQUENCE_SQLSERVER.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

/**
 * TableFilter_SEQUENCE_SQLSERVER は、TableUpda インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。
 *
 * ここでは、シーケンス一覧の検索結果より、GF09 のシーケンス定義テーブルから
 * 必要な情報を取得し、シーケンス作成スクリプトを作成します。
 *
 * この処理を実行するには、DBTableModelのカラムとして、
 *  SEQNAME,INCREBY,STARTVAL,MINVAL,MAXVAL,FGCYCLE,SUCACHE
 * が必要です。
 *
 * ※SQLServerに対して生成されるスクリプトでは、INCREBY,MINVAL,MAXVAL,FGCYCLE,SUCACHEは無視されます。
 *   なお、SQLServerではシーケンスはサポートされていないため、シーケンス名と同じ名前のシーケンス採番テーブルを生成し、
 *   これを1ずつ加算してアップデートすることで、シーケンスをエミュレートします。(この実装は未テストです)
 *
 * @og.rev 5.1.9.0 (2010/08/01) DB定義DB・シーケンス定義追加
 * @version  0.9.0  2010/08/01
 * @author   Hiroki Nakamura
 * @since    JDK1.1,
 */
public class TableFilter_SEQUENCE_SQLSERVER extends TableFilter_SEQUENCE {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.1.9.0 (2010/08/01)" ;

	/**
	 * シーケンス作成の処理を実行します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	シーケンス作成
	 */
	@Override
	protected String makeLineList( final int[] clmNo,final String[] data ) {
		StringBuilder buf = new StringBuilder();

		if( isXml ) { buf.append( EXEC_START_TAG ).append( CR ); }
		buf.append( "CREATE TABLE " ).append( data[clmNo[SEQNAME]] ).append( CR );
		buf.append( "  (SEQID INT NOT NULL)" );
//		buf.append( "(SEQID INT NOT NULL)" ).append( CR );
		if( isXml )	{ buf.append( CR ).append( EXEC_END_TAG ); }
		else		{ buf.append( " ;" ); }

		buf.append( CR ).append( CR );

		if( isXml ) { buf.append( EXEC_START_TAG ).append( CR ); }
//		buf.append( "INSERT INTO " ).append( data[clmNo[SEQNAME]] ).append( CR );
		int startVal = Integer.valueOf( data[clmNo[STARTVAL]] );
		if( startVal < 0 ) { startVal = 0; }
		buf.append( "INSERT INTO " ).append( data[clmNo[SEQNAME]] );
		buf.append( " VALUES (" ).append( startVal ).append( ")" );
		if( isXml )	{ buf.append( CR ).append( EXEC_END_TAG ); }
		else		{ buf.append( " ;" ); }

//		buf.append( CR );

		return buf.toString();
	}
}
